@@ -252,7 +252,7 @@ def do_release(
 
         elif effective_release_type == "major":
             # we only do major release if we have reached at least 1.0
-            if assignement.value[0].value != "0":
+            if release_type == "auto" and assignement.value[0].value != "0":
                 assignement.value[2].value = "0"
                 assignement.value[1].value = "0"
                 assignement.value[0].value = str(major + 1)
